==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/FinancialCalculationDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalculatedColumnDescriptionMetadata } from "./CalculatedColumnDescriptionMetadata";
import { FinancialCalculationDataSourceDescription } from "./FinancialCalculationDataSourceDescription";
/**
 * @hidden
 */
var FinancialCalculationDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialCalculationDataSourceDescriptionMetadata, _super);
    function FinancialCalculationDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialCalculationDataSourceDescriptionMetadata.b = function (a) {
        if (FinancialCalculationDataSourceDescriptionMetadata.a == null) {
            FinancialCalculationDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialCalculationDataSourceDescriptionMetadata.c(FinancialCalculationDataSourceDescriptionMetadata.a);
        }
        if (a.g(FinancialCalculationDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.s(FinancialCalculationDataSourceDescriptionMetadata.a);
        CalculatedColumnDescriptionMetadata.d(a);
    };
    FinancialCalculationDataSourceDescriptionMetadata.c = function (a) {
        a.item("TypicalColumn", "ExportedType:CalculatedColumn");
        a.item("TrueRange", "ExportedType:CalculatedColumn");
        a.item("TrueLow", "ExportedType:CalculatedColumn");
        a.item("Period", "Number:int");
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
        a.item("Count", "Number:int");
        a.item("CalculateFrom", "Number:int");
        a.item("CalculateCount", "Number:int");
        a.item("Multiplier", "Number:double");
        a.item("MinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("SpecifiesRange", "Boolean");
    };
    FinancialCalculationDataSourceDescriptionMetadata.d = function (a) {
        FinancialCalculationDataSourceDescriptionMetadata.b(a);
        a.u("FinancialCalculationDataSource", function () { return new FinancialCalculationDataSourceDescription(); });
        a.t("FinancialCalculationDataSource", FinancialCalculationDataSourceDescriptionMetadata.a);
    };
    FinancialCalculationDataSourceDescriptionMetadata.$t = markType(FinancialCalculationDataSourceDescriptionMetadata, 'FinancialCalculationDataSourceDescriptionMetadata');
    FinancialCalculationDataSourceDescriptionMetadata.a = null;
    return FinancialCalculationDataSourceDescriptionMetadata;
}(Base));
export { FinancialCalculationDataSourceDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/FinancialCalculationDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CalculatedColumnDescriptionMetadata } from "./CalculatedColumnDescriptionMetadata";
import { FinancialCalculationDataSourceDescription } from "./FinancialCalculationDataSourceDescription";
/**
 * @hidden
 */
var FinancialCalculationDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(FinancialCalculationDataSourceDescriptionMetadata, _super);
    function FinancialCalculationDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    FinancialCalculationDataSourceDescriptionMetadata.b = function (a) {
        if (FinancialCalculationDataSourceDescriptionMetadata.a == null) {
            FinancialCalculationDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            FinancialCalculationDataSourceDescriptionMetadata.c(FinancialCalculationDataSourceDescriptionMetadata.a);
        }
        if (a.j(FinancialCalculationDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.y(FinancialCalculationDataSourceDescriptionMetadata.a);
        CalculatedColumnDescriptionMetadata.d(a);
    };
    FinancialCalculationDataSourceDescriptionMetadata.c = function (a) {
        a.item("TypicalColumn", "ExportedType:CalculatedColumn");
        a.item("TrueRange", "ExportedType:CalculatedColumn");
        a.item("TrueLow", "ExportedType:CalculatedColumn");
        a.item("Period", "Number:int");
        a.item("ShortPeriod", "Number:int");
        a.item("LongPeriod", "Number:int");
        a.item("Count", "Number:int");
        a.item("CalculateFrom", "Number:int");
        a.item("CalculateCount", "Number:int");
        a.item("Multiplier", "Number:double");
        a.item("MinimumValue", "Number:double");
        a.item("MaximumValue", "Number:double");
        a.item("SpecifiesRange", "Boolean");
    };
    FinancialCalculationDataSourceDescriptionMetadata.d = function (a) {
        FinancialCalculationDataSourceDescriptionMetadata.b(a);
        a.aa("FinancialCalculationDataSource", function () { return new FinancialCalculationDataSourceDescription(); });
        a.z("FinancialCalculationDataSource", FinancialCalculationDataSourceDescriptionMetadata.a);
    };
    FinancialCalculationDataSourceDescriptionMetadata.$t = markType(FinancialCalculationDataSourceDescriptionMetadata, 'FinancialCalculationDataSourceDescriptionMetadata');
    FinancialCalculationDataSourceDescriptionMetadata.a = null;
    return FinancialCalculationDataSourceDescriptionMetadata;
}(Base));
export { FinancialCalculationDataSourceDescriptionMetadata };
